Class AxeDisplay

Private:

	Const pin_Display1 as Byte = B.1
	Const charPause as Integer = 10
	
	Function CursorStartPos (ByVal userNr as Byte) as Byte
		Select Case userNr
		Case 4
			CursorStartPos = 128		'row 1, pos 1'
		Case 3
			CursorStartPos = 128 + 8	'row 1, pos 9'
		Case 1
			CursorStartPos = 192		'row 2, pos 1'
		Case 2
			CursorStartPos = 192 + 8	'row 2, pos 2'
		Case Else
			CursorStartPos = 128
		End Select
	End Function

Public:

	Sub _Create()
		' configure the pin as an output
		Call PutPin(pin_Display1, zxOutputLow) ' Inverted idle state
		Call DelayMilliseconds(1000)
		Call ResetDisplay
	End Sub
	
	Sub DisplayString(ByRef zstring as String, ByVal userNr as Byte = 1)
		'First set cursor and line position properly
		Call SetCursor(userNr)
		'Now display the string message itself
		Dim i as Byte 		
		For i = 1 to Cbyte(len(zstring))
			Call SerialOut (Asc(zstring,i), pin_Display1, 2400)
			Call DelayMilliseconds(charPause)
		Next i
	End Sub

	Sub DisplayLine(ByRef zstring as String, ByVal lineNr as Byte = 1)
		Dim blankString as String = "                "
		If lineNr = 1 Then
			'First guarantee that the line is emptied before new text is added
			Call DisplayString(blankString,4)
			'Now display message on the proper line nr
			Call DisplayString(zstring,4)
		Else 
			Call DisplayString(blankString,1)
			'Now display message on the proper line nr
			Call DisplayString(zstring,1)
		End If
	End Sub
	
	Sub EchoCharacter(ByRef zchar as String)		
		Call SerialOut (zchar, pin_Display1, 2400)
		Call DelayMilliseconds(charPause)
	End Sub
	
	Sub SetCursor(ByVal userNr as Byte)
		Call SerialOut(Chr(254), pin_Display1, 2400)
		DelayMilliseconds(charPause)
		Call SerialOut (Chr(CursorStartPos(userNr)), pin_Display1, 2400)
		DelayMilliseconds(charPause)
	End Sub
	
	Sub ControlCursor(ByVal Show as Boolean, ByVal Blink as Boolean)
		Dim controlCode as Byte
		Call SerialOut (Chr(254), pin_Display1, 2400)
		Call DelayMilliseconds(charPause)
		controlCode = &B00001100
		If Show Then controlCode = controlCode + &B00000010
		If Blink Then ControlCode = controlCode + &B00000001
		Call SerialOut (Chr(controlCode), pin_Display1, 2400)
		Call DelayMilliseconds(charPause)
	End Sub
	
	Sub ClearLine(ByVal lineNr as Byte = 1)
		Dim blankString as String = "                "
		If lineNr = 1 Then
			Call DisplayString(blankString,4)
		Else
			Call DisplayString(blankString,1)
		End If
	End Sub
	
	Sub ClearDisplay()
		Dim clearDisplayStr as String = Chr(254) & Chr(1)
		Call DisplayString(clearDisplayStr)
		Call DelayMilliseconds(30)	'required by AXE033 display
	End Sub
	
	Sub ResetDisplay()
		Dim initStr as String = Chr(254) & Chr(128)
		Call DisplayString(initStr)
		Call clearDisplay
	End Sub
	
	Sub DisplayTest(ByRef message as String)
		Dim testString as String = "12345678"
		Dim i as Byte 
		For i = 1 to 10
			Call DisplayLine(message,1)
			DelayMilliseconds(500)
			Call ClearLine(1)
			Call DisplayLine(message,2)
			DelayMilliseconds(500)
			Call ClearDisplay
			DelayMilliseconds(500)
			Call DisplayString(testString,1)
			DelayMilliseconds(500)
			Call DisplayString(testString,2)
			DelayMilliseconds(500)
			Call DisplayString(testString,3)
			DelayMilliseconds(500)
			Call DisplayString(testString,4)
			DelayMilliseconds(1000)
			Call ResetDisplay
			DelayMilliseconds(200)
		Next i
	End Sub
	
End Class


